pub struct Account(pub Account);Expand description
Per account information stored in the state.
Tuple Fields
0: AccountImplementations
Sourceimpl Account
impl Account
Sourcepub const MAX_ACCOUNT_DELETION_STORAGE_USAGE: u64 = 10_000u64
pub const MAX_ACCOUNT_DELETION_STORAGE_USAGE: u64 = 10_000u64
Max number of bytes an account can have in its state (excluding contract code) before it is infeasible to delete.
pub fn new( amount: Balance, locked: Balance, code_hash: CryptoHash, storage_usage: StorageUsage, ) -> Self
Sourcepub fn code_hash(&self) -> CryptoHash
pub fn code_hash(&self) -> CryptoHash
CryptoHash: Hash of the code stored in the storage for this account.
Sourcepub fn storage_usage(&self) -> StorageUsage
pub fn storage_usage(&self) -> StorageUsage
int: Storage used by the given account, includes account id, this struct, access keys and other data.
Sourcepub fn version(&self) -> AccountVersion
pub fn version(&self) -> AccountVersion
AccountVersion: Version of Account in re migrations and similar
pub fn set_amount(&mut self, amount: Balance)
pub fn set_locked(&mut self, locked: Balance)
pub fn set_code_hash(&mut self, code_hash: CryptoHash)
pub fn set_storage_usage(&mut self, storage_usage: StorageUsage)
pub fn set_version(&mut self, version: AccountVersion)
pub fn __richcmp__(&self, other: &Self, op: CompareOp) -> PyResult<bool>
pub fn __bytes__<'a>(&self, py: Python<'a>) -> &'a PyBytes
pub fn __str__(&self) -> String
pub fn __repr__(&self) -> String
pub fn __reduce__(&self) -> PyResult<(PyObject, PyObject)>
Sourcepub fn from_bytes(data: &[u8]) -> PyResult<Self>
pub fn from_bytes(data: &[u8]) -> PyResult<Self>
Deserialize from bytes.
Args: data (bytes): the serialized object.
Returns: the deserialized object.