Module vm

Module vm 

Structs

AltBn128InvalidInput
Invalid input to alt_bn128 familiy of functions (e.g., point which isn’t on the curve).
CodeDoesNotExist
ContractSizeExceeded
The contract size for DeployContract action exceeded the limit.
Deprecated
The host function was deprecated.
ECRecoverError
General errors for ECDSA recover.
Ed25519VerifyInvalidInput
Invalid input to ed25519 signature verification function (e.g. signature cannot be derived from bytes).
GuestPanic
Smart contract panicked
InvalidIteratorIndex
Iterator index iterator_index does not exist
InvalidPromiseIndex
promise_idx does not correspond to existing promises
InvalidPromiseResultIndex
Accessed invalid promise result index
InvalidReceiptIndex
VM Logic returned an invalid receipt index
InvalidRegisterId
Accessed invalid register id
IteratorWasInvalidated
Iterator iterator_index was invalidated after its creation by performing a mutable operation on trie
KeyLengthExceeded
The storage key length exceeded the limit.
LinkError
Wasm binary env link error
NumberInputDataDependenciesExceeded
The maximum number of input data dependencies exceeded the limit.
NumberOfLogsExceeded
The total number of logs will exceed the limit.
NumberPromisesExceeded
The maximum number of promises within a FunctionCall exceeded the limit.
ProhibitedInView
method_name is not allowed in view calls
ReturnedValueLengthExceeded
The returned value length exceeded the limit.
SerializationError
TotalLogLengthExceeded
The total log length exceeded the limit.
UnsupportedCompiler
ValueLengthExceeded
The storage value length exceeded the limit.
WasmerCompileError

Enums

CacheError
CacheErrorFieldless
CompilationError
Wasm compilation error
FunctionCallErrorSer
Serializable version of FunctionCallError.
FunctionCallErrorSerFieldless
HostError
HostErrorFieldless
MethodResolveError
Import/export resolve error
PrepareError
Error that can occur while preparing or executing Wasm smart-contract.
WasmTrap
A kind of a trap happened during execution of a binary