pub struct ExecutionOutcome(pub ExecutionOutcome);Expand description
Execution outcome for one signed transaction or one receipt.
Tuple Fields
0: ExecutionOutcomeImplementations
Sourceimpl ExecutionOutcome
impl ExecutionOutcome
pub fn new( logs: Vec<String>, receipt_ids: Vec<CryptoHash>, gas_burnt: Gas, tokens_burnt: Balance, executor_id: AccountId, status: ExecutionStatus, metadata: ExecutionMetadata, ) -> Self
Sourcepub fn receipt_ids(&self) -> Vec<CryptoHash>
pub fn receipt_ids(&self) -> Vec<CryptoHash>
listCryptoHash: Receipt IDs generated by this transaction or receipt.
Sourcepub fn gas_burnt(&self) -> Gas
pub fn gas_burnt(&self) -> Gas
int: The amount of the gas burnt by the given transaction or receipt.
Sourcepub fn tokens_burnt(&self) -> Balance
pub fn tokens_burnt(&self) -> Balance
int: The amount of tokens burnt corresponding to the burnt gas amount.
This value doesn’t always equal to the gas_burnt multiplied by the gas price, because
the prepaid gas price might be lower than the actual gas price and it creates a deficit.
Sourcepub fn executor_id(&self) -> AccountId
pub fn executor_id(&self) -> AccountId
AccountId: The id of the account on which the execution happens. For transaction this is signer_id, for receipt this is receiver_id.
Sourcepub fn status(&self) -> ExecutionStatus
pub fn status(&self) -> ExecutionStatus
ExecutionStatus: Execution status. Contains the result in case of successful execution. NOTE: Should be the latest field since it contains unparsable by light client ExecutionStatus::Failure
Sourcepub fn metadata(&self) -> ExecutionMetadata
pub fn metadata(&self) -> ExecutionMetadata
ExecutionMetadata: Execution metadata, versioned
pub fn __richcmp__(&self, other: &Self, op: CompareOp) -> PyResult<bool>
pub fn __bytes__<'a>(&self, py: Python<'a>) -> &'a PyBytes
pub fn __str__(&self) -> String
pub fn __repr__(&self) -> String
pub fn __reduce__(&self) -> PyResult<(PyObject, PyObject)>
Sourcepub fn from_bytes(data: &[u8]) -> PyResult<Self>
pub fn from_bytes(data: &[u8]) -> PyResult<Self>
Deserialize from bytes.
Args: data (bytes): the serialized object.
Returns: the deserialized object.