Structs
- AltBn128
Invalid Input - Invalid input to alt_bn128 familiy of functions (e.g., point which isn’t on the curve).
- Code
Does NotExist - Contract
Size Exceeded - The contract size for DeployContract action exceeded the limit.
- Deprecated
- The host function was deprecated.
- ECRecover
Error - General errors for ECDSA recover.
- Ed25519
Verify Invalid Input - Invalid input to ed25519 signature verification function (e.g. signature cannot be derived from bytes).
- Guest
Panic - Smart contract panicked
- Invalid
Iterator Index - Iterator index
iterator_indexdoes not exist - Invalid
Promise Index promise_idxdoes not correspond to existing promises- Invalid
Promise Result Index - Accessed invalid promise result index
- Invalid
Receipt Index - VM Logic returned an invalid receipt index
- Invalid
Register Id - Accessed invalid register id
- Iterator
WasInvalidated - Iterator
iterator_indexwas invalidated after its creation by performing a mutable operation on trie - KeyLength
Exceeded - The storage key length exceeded the limit.
- Link
Error - Wasm binary env link error
- Number
Input Data Dependencies Exceeded - The maximum number of input data dependencies exceeded the limit.
- Number
OfLogs Exceeded - The total number of logs will exceed the limit.
- Number
Promises Exceeded - The maximum number of promises within a FunctionCall exceeded the limit.
- Prohibited
InView method_nameis not allowed in view calls- Returned
Value Length Exceeded - The returned value length exceeded the limit.
- Serialization
Error - Total
LogLength Exceeded - The total log length exceeded the limit.
- Unsupported
Compiler - Value
Length Exceeded - The storage value length exceeded the limit.
- Wasmer
Compile Error
Enums
- Cache
Error - Cache
Error Fieldless - Compilation
Error - Wasm compilation error
- Function
Call Error Ser - Serializable version of
FunctionCallError. - Function
Call Error SerFieldless - Host
Error - Host
Error Fieldless - Method
Resolve Error - Import/export resolve error
- Prepare
Error - Error that can occur while preparing or executing Wasm smart-contract.
- Wasm
Trap - A kind of a trap happened during execution of a binary